==> static-compat-qt6-wayland-6.9.3-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6WaylandCompositor/Qt6VulkanServerBufferIntegrationPluginDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

set(VulkanServerBufferIntegrationPlugin_FOUND TRUE)

# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_VulkanServerBufferIntegrationPlugin_third_party_deps "Wayland\;FALSE\;1.15\;\;")
_qt_internal_find_third_party_dependencies("VulkanServerBufferIntegrationPlugin" __qt_VulkanServerBufferIntegrationPlugin_third_party_deps)
unset(__qt_VulkanServerBufferIntegrationPlugin_third_party_deps)

set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_VulkanServerBufferIntegrationPlugin_target_deps "Qt6Core\;6.9.3;Qt6Gui\;6.9.3;Qt6OpenGL\;6.9.3;Qt6WaylandCompositor\;6.9.3;Qt6CorePrivate\;6.9.3;Qt6GuiPrivate\;6.9.3;Qt6OpenGLPrivate\;6.9.3;Qt6WaylandCompositorPrivate\;6.9.3")
set(__qt_VulkanServerBufferIntegrationPlugin_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/..;${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("VulkanServerBufferIntegrationPlugin" __qt_VulkanServerBufferIntegrationPlugin_target_deps
                                  __qt_VulkanServerBufferIntegrationPlugin_find_dependency_paths)
unset(__qt_VulkanServerBufferIntegrationPlugin_target_deps)
unset(__qt_VulkanServerBufferIntegrationPlugin_find_dependency_paths)

if(__qt_${target}_missing_deps)
    set(VulkanServerBufferIntegrationPlugin_FOUND FALSE)
endif()

==> static-compat-qt6-wayland-6.10.1-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6WaylandCompositor/Qt6VulkanServerBufferIntegrationPluginDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

set(VulkanServerBufferIntegrationPlugin_FOUND TRUE)

# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_VulkanServerBufferIntegrationPlugin_third_party_deps "Wayland\;FALSE\;1.15\;\;")
if(__qt_VulkanServerBufferIntegrationPlugin_third_party_deps)
    _qt_internal_find_third_party_dependencies("VulkanServerBufferIntegrationPlugin" __qt_VulkanServerBufferIntegrationPlugin_third_party_deps)
endif()
unset(__qt_VulkanServerBufferIntegrationPlugin_third_party_deps)

set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_VulkanServerBufferIntegrationPlugin_target_deps "Qt6Core\;6.10.1;Qt6Gui\;6.10.1;Qt6OpenGL\;6.10.1;Qt6WaylandCompositor\;6.10.1")
set(__qt_VulkanServerBufferIntegrationPlugin_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/..;${_qt_cmake_dir}")
if(__qt_VulkanServerBufferIntegrationPlugin_target_deps)
    _qt_internal_find_qt_dependencies("VulkanServerBufferIntegrationPlugin" __qt_VulkanServerBufferIntegrationPlugin_target_deps
                                      __qt_VulkanServerBufferIntegrationPlugin_find_dependency_paths)
endif()
unset(__qt_VulkanServerBufferIntegrationPlugin_target_deps)
unset(__qt_VulkanServerBufferIntegrationPlugin_find_dependency_paths)

if(__qt_${target}_missing_deps)
    set(VulkanServerBufferIntegrationPlugin_FOUND FALSE)
endif()
